#pragma once

#include <vector>
#include <map>

struct ADQInterface;

class CUtils
{
public:
	CUtils(int clock_source);
	~CUtils();
	struct SChannelSettings
	{
		SChannelSettings();
		float m_input_range;
		int dc_offset;
		bool m_input_impedance;
	};
	struct SModuleSettings
	{
		SModuleSettings();
		unsigned int m_level_trig_channel;
		int m_level_trig_level;
		int m_level_trig_arm_hyst;
		unsigned int m_level_trig_edge;
		unsigned int m_trigger_source;
		unsigned int m_pretrig_samples;
		unsigned int m_trigger_delay_samples;
		std::vector<SChannelSettings> m_channelsettings;
	};
	struct SSettings
	{
		SSettings(int clock_source);
		int m_clock_source;
		float m_ref_clock_delay_ps;
		unsigned int m_sample_skip_factor;
		unsigned int m_number_of_records;
		unsigned int m_record_length;
		std::map<int, SModuleSettings> m_masterModuleSettings;
		std::map<int, SModuleSettings> m_slaveModuleSettings;
	};
	void list_devices();
	void detect_daisy_chain_order();
	void adjust_pre_trigger_samples(int adq_num, int position, SModuleSettings& modulesettings);
	void adjust_pre_trigger_samples();
	void setup_daisy_chain(int adq_num, int position, SModuleSettings const& modulesettings) const;
	void setup_daisy_chain() const;
	void fill_daisy_chain_device_information();
	void setup_collection(int adq_num, SModuleSettings const& modulesettings) const;
	void setup_collection() const;
	void arm_all() const;
	void enable_daisy_chain_all() const;
	void send_triggers(int adq_num, SModuleSettings const& modulesettings) const;
	void send_triggers() const;
	bool wait_for_acquired_all();
	void collect_data(int adq_num);
	void collect_data_all();
	void save_data() const;
	void ThrowException(unsigned int status, std::string const& ErrorSource, bool ThrowIt = true) const;
private:
	void* m_adq_cu;					// The ADQ control unit object.
	SSettings m_settings;
	std::vector<ADQInterface*> m_adqInterfaces;					// The list of ADQ objects
	std::vector<std::vector<std::vector<unsigned short*>>> m_target_buffers;
	std::vector<double> m_timeStamps;
	int		m_nof_adqs;
	std::map<int, std::vector<int>> m_device_position;
	std::vector<std::vector<int64_t>> m_RecordStart;
	void close_all_devices() const;
};