/*
 *   Copyright 2018 Teledyne Signal Processing Devices Sweden AB
 */

#ifndef ADQINIT_H
#define ADQINIT_H

class ADQAIChannelGroup;

#include <nds3/nds.h>

/** @file ADQInit.h
 * @brief This file defines ADQInit class that creates a device.
 */

/** @brief This class creates a device that communicates with a digitizer.
 * ADQ Control Unit is handled by this class. The pointer to ADQAPI interface is also created here.
 */
class ADQInit
{
public:
    /** @fn ADQInit(nds::Factory& factory, const std::string& deviceName, const nds::namedParameters_t& parameters);
     * @brief ADQInit class constructor.
     * @param factory contains an interface to the EPICS that requested a creation of the NDS device.
     * @param deviceName a name of the root node through which the EPICS can communicate with the NDS device.
     * @param parameters here a serial number of the requested digitizer is passed to the NDS device. 
     */
    ADQInit(nds::Factory& factory, const std::string& deviceName, const nds::namedParameters_t& parameters);
    ~ADQInit();

private:
    class CADQControl;
    static CADQControl* m_ADQControl;
    nds::Node m_node;
    std::string m_adqSnRdbk;
    void CloseDevice();

    // Vector of pointers to Group channel class
    ADQAIChannelGroup* m_adqChanGrpPtr;
};

#endif /* ADQINIT_H */
